# TaxExemptStatus

Status of the account tax exemption. Applicable if you use Zuora Tax or Connect tax engines. Required if you use Zuora Tax.  

## Enum

* `NO` (value: `'No'`)

* `YES` (value: `'Yes'`)

* `PENDINGVERIFICATION` (value: `'PendingVerification'`)

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


